@@ -2,7 +2,7 @@ from datetime import datetime, date
 
 from tzlocal import get_localzone
 
-from util.date_time_util import insure_localisation
+from .util.date_time_util import insure_localisation
 
 
 class Duration:
